Add border to any cells at any side.
Arguments
- plot
A forest plot object.
- row
A numeric value or vector indicating row number to add border. This is corresponding to the data row number. Remember to account for any text inserted. A border will be drawn to all rows if this is omitted.
- col
A numeric value or vector indicating the columns to add border. A border will be drawn to all columns if this is omitted.
- part
The border will be added to
"body"(default) or"header".- where
Where to draw the border of the cell, possible values are
"bottom"(default),"left","top"and"right"- gp
An object of class
"gpar", graphical parameter to be passed tosegmentsGrob.
Value
A gtable object.