Show the settings of a style that are not the default ones.
Usage
# S3 method for class 'forest_style'
print(x, ...)Arguments
- x
A style created with
forest_style.- ...
other arguments not used by this method
Show the settings of a style that are not the default ones.
# S3 method for class 'forest_style'
print(x, ...)A style created with forest_style.
other arguments not used by this method