This function can be used to add text to a forest plot. The text can span multiple rows and columns. The height of the row will be adjusted accordingly if the text is added to only one row. The width of the text may exceed the columns provided if the text is too long.
Arguments
- plot
A forest plot object.
- text
A character or expression vector, see
textGrob.- row
Row to add the text, this will be ignored if the
partis "header".- col
A numeric value or vector indicating the columns the text will be added. The text will span over the column if a vector is given.
- part
Part to add text,
"body"(default) or"header".- just
The justification of the text,
"center"(default),"left"or"right".- gp
An object of class
"gpar", this is the graphical parameter settings of the text. Seegpar.- padding
Padding of the text, default is
unit(1, "mm")- parse
Logical, behaviour for parsing text as plotmath, see
plotmath
Value
A gtable object.