| check_errors | R Documentation |
The settings of the x-axis and the labels are checked by
set_xaxis and set_labs.
check_errors(data, est, lower, upper, sizes, ref_line, ci_column, is_summary)
data |
Data to be displayed in the forest plot |
est |
Point estimation. Can be a list for multiple columns
and/or multiple groups. If the length of the list is larger than
then length of |
lower |
Lower bound of the confidence interval, same as |
upper |
Upper bound of the confidence interval, same as |
sizes |
Size of the point estimation box, can be a vector or a list.
The value is a multiple of one line of text, so |
ref_line |
X-axis coordinates of the reference line, the value of no
effect. If |
ci_column |
Column number of the data the CI will be displayed. |
is_summary |
A logical vector indicating if the value is a summary value,
which will have a diamond shape for the estimate. With multiple groups the
diamonds are stacked in the same cell and the summary rows are made taller to
fit them, so a larger |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.