This function is used to edit the graphical parameters of text and background of the forest plot.
Arguments
- plot
A forest plot object.
- row
A numeric value or vector indicating row number to edit in the dataset. Will edit the whole row if left blank for the body. This will be ignored if the
partis "header".- col
A numeric value or vector indicating column to edit in the dataset. Will edit the whole column if left blank.
- part
Part to edit,
"body"(default) or"header".- which
Which element to edit,
"text","background"or"ci"(confidence interval). This will not edit diamond shaped summary CI, please change it withforest_theme. Also, change inciwill not have any impact on the legend.- gp
Pass
gparparameters, seegpar. It should be passed asgpar(col = "red"). Forwhich = "ci", please refer toforest_themeci_*parameters for the editable elements.- ...
Other parameters to be passed to the grobs. See
textGrobfor the"text"part andrectGrobfor"background". This is ignored whenwhich = "ci"because non-graphical parameters cannot be changed for the confidence interval.
Value
A gtable object.