This function can be used to insert text into a forest plot. Remember to adjust for the row number if you have added text before, including the header. This is achieved by inserting new row(s) into the plot and will affect subsequent row numbers. A text vector can be inserted into multiple columns or rows.
Arguments
- plot
A forest plot object.
- text
A character or expression vector, see
textGrob.- row
Row to insert the text, this will be ignored if the
partis "header".- col
A numeric value or vector indicating the columns the text will be added. The text will span over the column if a vector is given.
- part
Part to insert text,
"body"(default) or"header".- just
The justification of the text,
"center"(default),"left"or"right".- before
Indicating the text will be inserted before or after the row.
- gp
An object of class
"gpar", this is the graphical parameter settings of the text. Seegpar.- padding
Padding of the text, default is
unit(1, "mm")- parse
Logical, behaviour for parsing text as plotmath, see
plotmath
Value
A gtable object.