| make_xlim | R Documentation |
Create xlim based on value ranges.
make_xlim(
xlim = NULL,
lower,
upper,
ref_line = ifelse(x_trans %in% c("log", "log2", "log10"), 1, 0),
ticks_at = NULL,
x_trans = "none"
)
xlim |
Limits for the x-axis as a vector of length 2, i.e.
|
lower |
Lower bound of the confidence interval, same as |
upper |
Upper bound of the confidence interval, same as |
ref_line |
X-axis coordinates of the reference line, the value of no
effect. If |
ticks_at |
Tick mark positions. By default, ticks are computed
automatically: |
x_trans |
Scale of the axis, one of |
A list
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.