Create confidence interval grob
Arguments
- est
Point estimation. Can be a list for multiple columns and/or multiple groups. If the length of the list is larger than then length of
ci_column, then the values reused for each column and considered as different groups.- lower
Lower bound of the confidence interval, same as
est.- upper
Upper bound of the confidence interval, same as
est.- pch
Numeric or character vector indicating what sort of plotting symbol to use. See
pointsGrob.- sizes
Size of the point estimation box, can be a vector or a list. The value is a multiple of one line of text, so
1draws a point as tall as thebase_sizeof the theme. The same scale applies to the summary diamond. Values are used as they are, unlessscale_sizesis used to read them as study weights; useful values are roughly between0.2and1.5, and a warning is given when the plot is drawn if they are outside0.1to2.- gp
Graphical parameters of
gpar. Please refer toforest_themefor more details.- t_height
The height of the confidence interval line end vertices. If the value is
NULL(default), no vertices will be drawn.- xlim
Limits for the x-axis as a vector of length 2, i.e.
c(low, high). By default the minimum and maximum of the lower and upper values are used.- nudge_y
Vertical adjustment to nudge groups by, must be within 0 to 1. Defaults to
0; for grouped forest plots a value of0is bumped to0.1automatically so that group CIs do not overplot. Set explicitly to override.- name
Name of the grob.